%% $Id: herschelformnormal.cls,v 1.0 2007/07/24 $
%%
%% HERSCHELFORM class file (ported from esoform.sty)
%% A M Chavan, ESO, 19-May-2003
%%
%% Copyright 1998-2003 by the European Southern Observatory
%% Adapted for Herschel Space Observatory as herschelformnormal with 
%% the permission and approval of ESO.
%%
%% M R Kidger & R Lorente, HSC, June 2007
%%
%% Revised for GT1 and OT1 Calls:
%%
%% M R Kidger & R Lorente, HSC, 25 February 2010
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%                                                       %%
%% Revised for GT2 and OT2 Calls:                        %%
%%                                                       %%
%% M R Kidger & R Lorente, HSC, 31 March 2011            %%
%%                                                       %%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%



\ProvidesClass{herschelformnormal}
\LoadClass{article}
\RequirePackage{common2enormal}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      normal Programme Declaration
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

\normalProgramme

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Page 1
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageSum
%%
%% Generate page 1 layout for normal programmes.
%%
\def\@MakePageSum{

        \begin{picture}(\@pageWidth,\@pageonelength)

        \makebox(\@pageWidth,\@pageonelength)[tl]{
                \vbox{
                        \MakeSumBox
                        \MakePageNumber
                }
        }

        \end{picture}
        \vfill
        \pagebreak
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Page 1
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageSumAlt
%%
%% Generate page 1 layout for normal programmes.
%%
\def\@MakePageSumAlt{

        \begin{picture}(\@pageWidth,\@pageonelength)

        \makebox(\@pageWidth,\@pageonelength)[tl]{
                \vbox{
                        \MakeSumAltBox
                        \MakePageNumber
                }
        }

        \end{picture}
        \vfill
        \pagebreak
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Pages 2-4
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageDesc
%%
%% Generate pages 2-4 layout for normal programmes.
%%
\def\@MakePageDesc{

        \MakeDescriptionPages
}

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Page 5
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageTech
%%
%% Generate pages 5 layout for normal programmes.
%%
\def\@MakePageTech{
        \MakeTechnicalPages
}


     

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Pages 6
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageDPros
%%
%% Generate page 6 layout for normal programmes.
%%
\def\@MakePageDPros{
        \MakeDPPlans
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Pages 7
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageOut
%%
%% Generate page 7 layout for normal programmes.
%%
\def\@MakePageOut{
        \MakeOutreach
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Pages 8
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageFifteen
%%
%% Generate page 8 layout for normal programmes.
%%
\def\@MakeTargetListPage{

        \begin{picture}(\@pageWidth,\@pagetwolength)

        \makebox(\@pageWidth,\@pagetwolength)[tl]{
                \vbox{
                        \MakeTargets
                        \MakePageNumber
                }
        }

        \end{picture}
        \vfill
        \pagebreak
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Page 9
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakePageMembers
%%
%% Generate page 9 layout for normal programmes.
%%


\def\@MakePageMembers{
\MakeMembers
}



%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Additional and uncontrolled pages
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%% Generate pages 12 to finish layout for normal programmes.
%%

  \vfill
  \pagebreak
  

%  \if@too
%    \@MakeTOOPage
%  \fi             

%% Macro: @MakeMembersPage
%%
%% Generate team members page layout for normal programmes.
%%
\def\@MakeMembersPage{

        \begin{picture}(\@pageWidth,\@pagetwolength)

        \makebox(\@pageWidth,\@pagetwolength)[tl]{
                \vbox{
                        \MakeMembers
                        \MakePageNumber
                }
        }

        \end{picture}
        \vfill
        \pagebreak
}



%% Macro: @MakeTOOPage
%%
%% Generate ToO page layout.
%%
\def\@MakeTOOPage{

        \begin{picture}(\@pageWidth,\@pagetwolength)

        \makebox(\@pageWidth,\@pagetwolength)[tl]{
                \vbox{
                        \MakeTOOBox
                        \MakePageNumber
                }
        }

        \end{picture}
        \vfill
        \pagebreak
}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Overflow page
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: @MakeOptionalPages
%%
%% Generate an overflow page for extra information
%%
\def\@MakeOptionalPages{

  %% If needed, make the \INSConfig overflow page
  %%------------------------------------------------------------
  \ifnum\the\@instConfCounter>\@instConfCounterMax
    \begin{picture}(\@pageWidth,\@pagetwolength)
      \makebox(\@pageWidth,\@pagetwolength)[tl]{
        \vbox{
          \MakeInstrumentConfBoxB
          \MakePageNumber
        }
      }

    \end{picture}
    \vfill
    \pagebreak
  \fi


  %% If needed, make the \ObsRuns overflow page
  %%------------------------------------------------------------
  \ifnum\the\@obsRunCounterOverflow>0
  \begin{picture}(\@pageWidth,\@pagetwolength)
    
    \makebox(\@pageWidth,\@pagetwolength)[tl]{
      \vbox{
        \MakeOverflowRunsBox
        \MakePageNumber
      }
    }

  \end{picture}
  \vfill
  \pagebreak
  \fi


%% If needed, make the \Target overflow page
  %%------------------------------------------------------------
  \@targetsOverflowPage=1
  \loop
  \expandafter\ifx\csname TargetList\the\@targetsOverflowPage\endcsname\relax
  \else
  \begin{picture}(\@pageWidth,\@pagetwolength)
    \makebox(\@pageWidth,\@pagetwolength)[tl]{
      \vbox{
        \MakeOverflowTargets{\the\@targetsOverflowPage}%
        \MakePageNumber
        \global\advance\@targetsOverflowPage by 1
      }
    }
  \end{picture}
  \vfill
  \pagebreak
  \repeat


}


%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%
%%      Make all the document
%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%% Macro: MakeProposal
%%
%%
\def\MakeProposal{
        \@MakePageDesc
        \@MakePageTech
        \@MakePageDPros
        \@MakePageOut
%        \@MakePageMembers
%        \@MakeTOOPage
%        \@MakePageSum
%        \@MakePageSumAlt
%        \@MakeOptionalPages     % create some pages, but then maybe not.
}
